@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*- #
 
 from functools import partial
-from time import sleep
 from typing import Dict, Union
 
 from pyclvm._common.azure_instance_mapping import AzureRemoteShellProxy
@@ -21,12 +20,8 @@ def _connect(
     instance: Union[GcpRemoteShellProxy, AzureRemoteShellProxy],
     **kwargs,
 ) -> None:
-    pre_state = True if "running".upper() in instance.state.upper() else False
-
     print(f"Starting {instance_name} ...")
     instance.start()
-    if not pre_state:
-        sleep(15)
     print(f"{instance_name} is running")
 
     print(f"Connecting to {instance_name} ...")
