@@ -1,16 +1,17 @@
 from typing import Final, Tuple
 
+from ec2instances.common.session import get_session
 from rich.console import Console
 from rich.table import Table
 
-from pyclvm._common.session import get_session
-
 _COLUMNS: Final[Tuple[str, ...]] = ("SessionId", "Target", "DocumentName", "Owner")
 
 
 def ls(**kwargs: str) -> None:
     """
-    List all ssm session
+
+    list all ssm session
+
 
     Args:
         **kwargs (str): (optional) classifiers, at the moment, profile name
